# File-Name:       MSBVAR JCR Gaza Paper              
# Date:            2009-09-12                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:      
# Packages Used:    vars,foreign,MASS,tseries,urca,apsrtable,stats,MSBVAR          
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac


library(vars)
library(foreign)
library(MASS)
library(tseries)
library(urca)
library(apsrtable)
library(stats)
library(MSBVAR)

###Reading the data aggregated at 6 hours into
unscaled<-read.dta(file="Gaza_agg_6h.dta")
summary(unscaled)
Israel<-unscaled$israel_6h
sd(Israel)
Hamas<-unscaled$hamas_6h
sd(Hamas)
hours<-unscaled$hours




###Setting up the data and standardizing where hamas and israel residuals are equal to 1 (for IRF analysis)


israel.gaza<-cbind(Hamas,Israel)
israel.ts<-ts(data=israel.gaza, start = 1, end = 100, frequency = 1)
###Plotting Israel
plot(Israel, xlab="hours", ylab="Israel conflict intensity", ylim=c(0,400),pch=8,col="blue",cex=.5)
lines(Israel,lwd=c(.75),lty=c(1),col=c("blue"))
text(88,100,"Israeli cease-fire", cex=.5)
text(30,300,"Ground Invasion Begins", cex=.5)
text(90,80,"Hamas cease-fire", cex=.5)
text(40,200,"UNRWA school hit", cex=.5)
text(52,150, "UN Secur. Coun.", cex=.5)
text(76,160, "IDF enter Gaza City", cex=.5)
text(60,180,"IAF hits Hamas targets",cex=.5)
text(5,190,"Op. begin w/ IAF strikes",cex=.5)
text(17,120,"Constant Hamas rockets",cex=.5)
###Plotting Hamas
plot(Hamas, xlab="hours", ylab="Hamas conflict intensity", ylim=c(0,400),pch=2,col="red",cex=.5)
lines(Hamas,lwd=c(.75),lty=c(1),col=c("red"))
text(88,45,"Israeli cease-fire", cex=.5)
text(30,300,"Ground Invasion Begins", cex=.5)
text(90,80,"Hamas cease-fire", cex=.5)
text(40,200,"UNRWA school hit", cex=.5)
text(52,150, "UN Secur. Coun.", cex=.5)
text(76,160, "IDF enter Gaza City", cex=.5)
text(60,180,"IAF hits Hamas targets",cex=.5)
text(5,190,"Op. begin w/ IAF strikes",cex=.5)
text(17,240,"Constant Hamas rockets",cex=.5)

###Creating Exogenous variables and checking different lag lengths#######

###Exogenous variables
exog=cbind(unscaled$un,unscaled$invasion)
exog
israel.gaza<-cbind(Hamas,Israel)
hamas.gaza<-cbind(Israel,Hamas)
israel.ts<-ts(data=israel.gaza, start = 1, end = 100, frequency = 1)
hamas.ts<-ts(data=hamas.gaza, start = 1, end = 100, frequency = 1)
###Checking lag length
var.lag.specification(israel.ts, lagmax = 12) 

###Granger Test####
granger.test(israel.ts, 4)


### Using MSBVAR to estimate the model############

###The 4-lag model
short.MSBVAR <- reduced.form.var(israel.ts, p=4,z=exog) 
summary(short.MSBVAR)




###Comparing models where Hamas and Israel are initially constrained at zero and their forecast error decomposition

israel.msbvar<- reduced.form.var(israel.ts, p=4)
hamas.msbvar<- reduced.form.var(hamas.ts, p=4)
israel.dfev<-dfev(israel.msbvar,k=12)
hamas.dfev<-dfev(hamas.msbvar,k=12)

summary(israel.dfev)
summary(hamas.dfev)

###Checking the Standard Deviation
sd(Israel)
sd(Hamas)

###Normalizing the data and dividing Hamas and Israel by their standard deviation to get IRF shocks=1  ###
israel<-Israel/sd(Israel)
hamas<-Hamas/sd(Hamas)

###Creating the data set for the scaled conflict, and log scaled
scaled<-data.frame(cbind(hours,hamas,israel))
summary(scaled)


hamas<-scaled$hamas
israel<-scaled$israel
log.hamas<-log(hamas+1)
log.israel<-log(israel+1)

israel.data<-cbind(hamas,israel)
hamas.data<-cbind(israel,hamas)
log.israel.data<-cbind(log.hamas,log.israel)
summary(log.israel.data)

israel.ts<-ts(data=israel.data, start = 1, end = 100, frequency = 1)
hamas.ts<-ts(data=hamas.data, start = 1, end = 100, frequency = 1)
log.israel.ts<-ts(data=log.israel.data, start = 1, end = 100, frequency = 1)

###Comparing Models for scaled and log scaled and hamas constrained at zero initially by ordering hamas first
israel.var<-reduced.form.var(israel.ts,p=4)
log.israel.var<-reduced.form.var(log.israel.ts,p=4)
hamas.var<-reduced.form.var(hamas.ts,p=4)

###Colnames
varnames <- colnames(israel.ts)
var.h<-colnames(hamas.ts)

###Subsetting the data before the Invasion
pre.invasion<-subset(scaled,scaled$hours<30)
israel<-pre.invasion$israel
hamas<-pre.invasion$hamas


###Creating the Pre-Invasion Data Set and its VAR
pre.war<-cbind(hamas,israel)
pre.war.ts<-ts(data=pre.war, start = 1, end = 29, frequency = 1)
pre.war.var<- reduced.form.var(pre.war.ts, p=4)


###Subsetting the data after the Invasion
invasion<-subset(scaled,scaled$hours>=30)
israel<-invasion$israel
hamas<-invasion$hamas
length(israel)

##Creating the post Invasion data set
war<-cbind(hamas,israel)
war.ts<-ts(data=war, start = 1, end = 71, frequency = 1)
war.var<-reduced.form.var(war.ts,p=4)

###Creating the pre-UN Security council vote
pre.un<-subset(scaled,scaled$hours<52)
israel<-pre.un$israel
hamas<-pre.un$hamas

###Creating the Pre-UN Sec. Council data set
pre.vote<-cbind(hamas,israel)
pre.vote.ts<-ts(data=pre.vote, start = 1, end = 51, frequency = 1)
pre.vote.var<-reduced.form.var(pre.vote.ts,p=4)

###Creating the Post-UN Sec. Council data set
post.un<-subset(scaled,scaled$hours>=52)
israel<-post.un$israel
hamas<-post.un$hamas

###Creating the Pre-UN Sec. Council data set
post.vote<-cbind(hamas,israel)
post.vote.ts<-ts(data=post.vote, start = 1, end = 52, frequency = 1)
post.vote.var<-reduced.form.var(post.vote.ts,p=4)

###Plotting the IRF's

##The Whole Conflict
israel.impulses<- mc.irf(israel.var, nsteps=16, draws=10000)

i2h.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
matplot(i2h.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

h2i.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
matplot(h2i.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

h2h.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,1]
matplot(h2h.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"), xlab = "Hours after Hamas shock", ylab = "Hamas Response Intensity",ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

i2i.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,4]
matplot(i2i.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

###Pre Invasion

pre.war.impulses <- mc.irf(pre.war.var, nsteps=16, draws=10000) 
plot(pre.war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

###Post Invasion

war.impulses <- mc.irf(war.var, nsteps=16, draws=10000) 
plot(war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

###Pre UN
pre.vote.impulses <- mc.irf(pre.vote.var, nsteps=16, draws=10000) 
plot(pre.vote.impulses,method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

###Post UN
post.vote.impulses <- mc.irf(post.vote.var, nsteps=16, draws=10000) 
plot(post.vote.impulses,method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)
