# File-Name:       MSBVAR JCR Gaza Paper              
# Date:            2009-09-12                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:      
# Packages Used:    vars,foreign,MASS,tseries,urca,apsrtable,stats,MSBVAR          
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac


library(vars)
library(foreign)
library(MASS)
library(tseries)
library(urca)
library(apsrtable)
library(stats)
library(MSBVAR)

###Reading the Data into
unscaled<-read.dta(file="Gaza_no_postures.dta")
summary(unscaled)
Israel<-unscaled$israel
Hamas<-unscaled$hamas
hours<-unscaled$hours


###Checking the Standard Deviation
sd(Israel)
sd(Hamas)

###Normalizing the data and dividing Hamas and Israel by their standard deviation to get IRF shocks=1  ###
israel<-Israel/sd(Israel)
hamas<-Hamas/sd(Hamas)

###Creating the data set for the scaled conflict, and log scaled
scaled<-data.frame(cbind(hours,hamas,israel))
summary(scaled)


hamas<-scaled$hamas
israel<-scaled$israel
log.hamas<-log(hamas+1)
log.israel<-log(israel+1)

israel.data<-cbind(hamas,israel)
hamas.data<-cbind(israel,hamas)
log.israel.data<-cbind(log.hamas,log.israel)
summary(log.israel.data)

israel.ts<-ts(data=israel.data, start = 1, end = 598, frequency = 1)
hamas.ts<-ts(data=hamas.data, start = 1, end = 598, frequency = 1)
log.israel.ts<-ts(data=log.israel.data, start = 1, end = 598, frequency = 1)

###Granger tests
granger.test(israel.ts, 5)
granger.test(israel.ts, 9)


###Comparing Models for 9-lag, scaled and log scaled and hamas constrained at zero initially by ordering hamas first
long.israel.var<-reduced.form.var(israel.ts,p=9)
israel.var<-reduced.form.var(israel.ts,p=5)
log.israel.var<-reduced.form.var(log.israel.ts,p=5)
hamas.var<-reduced.form.var(hamas.ts,p=5)

###Colnames
varnames <- colnames(israel.ts)
var.h<-colnames(hamas.ts)

###Subsetting the data before the Invasion
pre.invasion<-subset(scaled,scaled$hours<174)
israel<-pre.invasion$israel
hamas<-pre.invasion$hamas


###Creating the Pre-Invasion Data Set and its VAR
pre.war<-cbind(hamas,israel)
pre.war.ts<-ts(data=pre.war, start = 1, end = 173, frequency = 1)
pre.war.var<- reduced.form.var(pre.war.ts, p=5)


###Subsetting the data after the Invasion
invasion<-subset(scaled,scaled$hours>=174)
israel<-invasion$israel
hamas<-invasion$hamas


##Creating the post Invasion data set
war<-cbind(hamas,israel)
war.ts<-ts(data=war, start = 1, end = 425, frequency = 1)
war.var<-reduced.form.var(war.ts,p=5)

###Creating the pre-UN Security council vote
pre.un<-subset(scaled,scaled$hours<306)
israel<-pre.un$israel
hamas<-pre.un$hamas

###Creating the Pre-UN Sec. Council data set
pre.vote<-cbind(hamas,israel)
pre.vote.ts<-ts(data=pre.vote, start = 1, end = 305, frequency = 1)
pre.vote.var<-reduced.form.var(pre.vote.ts,p=5)

###Creating the Post-UN Sec. Council data set
post.un<-subset(scaled,scaled$hours>=306)
israel<-post.un$israel
hamas<-post.un$hamas

###Creating the Pre-UN Sec. Council data set
post.vote<-cbind(hamas,israel)
post.vote.ts<-ts(data=post.vote, start = 1, end = 293, frequency = 1)
post.vote.var<-reduced.form.var(post.vote.ts,p=5)

###Plotting the IRF's and getting the Cumulative IRFs Figures 2-8###

##Israel VAR over the whole conflict (9-lag)######

long.israel.impulses<- mc.irf(long.israel.var, nsteps=18, draws=10000)
h2h.israel.var<-plot(long.israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,1]
matplot(h2h.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"), xlab = "Hours after Hamas shock", ylab = "Hamas Response Intensity",ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

i2h.israel.var<-plot(long.israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
matplot(i2h.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

h2i.israel.var<-plot(long.israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
matplot(h2i.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

i2i.israel.var<-plot(long.israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,4]
matplot(i2i.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,18))
abline(0,0)

###Israel VAR over the whole conflict (5-Lags)
israel.impulses<- mc.irf(israel.var, nsteps=12, draws=10000)
h2h.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,1]
matplot(h2h.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"), xlab = "Hours after Hamas shock", ylab = "Hamas Response Intensity",ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

i2h.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
apply(i2h.israel.var,2,cumsum)
matplot(i2h.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

h2i.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
apply(h2i.israel.var,2,cumsum)
matplot(h2i.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

i2i.israel.var<-plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,4]
matplot(i2i.israel.var, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)


###Log transformatin and Hamas ordered first########
log.israel.impulses<- mc.irf(log.israel.var, nsteps=12, draws=10000)
plot(log.israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)
hamas.impulses<-mc.irf(hamas.var, nsteps=25, draws=10000)
plot(hamas.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=var.h)

###Pre Invasion

pre.war.impulses <- mc.irf(pre.war.var, nsteps=12, draws=10000) 
plot(pre.war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)


i2h.pre.war<-plot(pre.war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
apply(i2h.pre.war,2,cumsum)
matplot(i2h.pre.war, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

h2i.pre.war<-plot(pre.war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
apply(h2i.pre.war,2,cumsum)
matplot(h2i.pre.war, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)


###Post Invasion

war.impulses <- mc.irf(war.var, nsteps=12, draws=10000) 
plot(war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

i2h.war<-plot(war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
apply(i2h.war,2,cumsum)
matplot(i2h.war, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

h2i.war<-plot(war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
apply(h2i.war,2,cumsum)
matplot(h2i.war, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

###Pre UN
pre.vote.impulses <- mc.irf(pre.vote.var, nsteps=12, draws=10000) 
plot(pre.vote.impulses,method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

i2h.pre.vote<-plot(pre.vote.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
apply(i2h.pre.vote,2,cumsum)
matplot(i2h.pre.vote, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

h2i.pre.vote<-plot(pre.vote.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
apply(h2i.pre.vote,2,cumsum)
matplot(h2i.pre.vote, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

###Post UN
post.vote.impulses <- mc.irf(post.vote.var, nsteps=12, draws=10000) 
plot(post.vote.impulses,method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

i2h.vote<-plot(post.vote.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,2]
apply(i2h.vote,2,cumsum)
matplot(i2h.vote, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Hamas shock", ylab="Israel Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)

h2i.vote<-plot(post.vote.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)$responses[,,3]
apply(h2i.vote,2,cumsum)
matplot(h2i.vote, type="l",lty=c(3,3,1),lwd=c(2,2,2),col=c("red","red","black"),xlab="Hours after Israel shock", ylab="Hamas Response Intensity", ylim=c(-.2,.8),xlim=c(1,12))
abline(0,0)
